@@ -1,3 +1,4 @@
+import os
 from dataclasses import dataclass
 from typing import Optional
 
@@ -60,6 +61,7 @@ class PreTrainConfig:
 @dataclass
 class NetworkConfig:
     """Define the neural network parameters"""
+    num_workers: int = 0  #: number of cores to use
     embedding_size: int = 10  #: dimension of computed embeddings
     depth: int = 3  #: number of attention blocks used in the transformer
     heads: int = 1  #: number of heads used in the transformer
@@ -67,6 +69,8 @@ class NetworkConfig:
     attention_type: str = 'col'  #: type of attention can be the self attention or intersample attention
     learning_rate: float = 0.03  #: value used to specify the learning rate for the optimizer
     learning_rate_pretraining: float = 0.03  #: value used to specify the learning rate for the optimizer pretraining
+    internal_dimension_output_layer: int = 20  #: internal dimension of the MLP that compute the output
+    internal_dimension_embed_continuous: int = 100  #: internal dimension of the mlp used to project continuous columns
 
 
 @dataclass
