@@ -33,6 +33,7 @@ class SAINT(LightningModule):
             mc_dropout: bool = False
     ):
         super().__init__()
+        self.save_hyperparameters()
         assert all(map(lambda n: n > 0, categories)), 'number of each category must be positive'
         self.mc_dropout = mc_dropout
         self.config = config
@@ -58,8 +59,7 @@ class SAINT(LightningModule):
         self._define_projection_head()
         self.mlpfory = SimpleMLP(self.config.network.embedding_size * self.num_columns,
                                  self.config.network.internal_dimension_output_layer, self.dim_target,
-                                 dropout=self.config.network.ff_dropout,
-                                 output_layer=nn.Softmax() if self.dim_target > 1 else None)
+                                 dropout=self.config.network.ff_dropout)
 
     def _define_transformer(self) -> None:
         """Instantiate the type of Transformed that will be used in SAINT"""
@@ -235,8 +235,6 @@ class SAINT(LightningModule):
     def forward(self, x_categ: Tensor, x_cont: Tensor) -> Tensor:
         x_categ_enc, x_cont_enc = self._embed_data(x_categ, x_cont)
         reps = self.transformer(x_categ_enc, x_cont_enc)
-        # select only the representations corresponding to y and apply mlp on it
-        # in the next step to get the predictions.
         reps = rearrange(reps, 'b h n -> b (h n)')
         y_outs = self.mlpfory(reps)
         return y_outs
@@ -280,7 +278,7 @@ class SAINT(LightningModule):
 
     def validation_step(self, batch: Tuple[Tensor, Tensor, Tensor], batch_idx: int) -> Tensor:
         loss = self.shared_step(batch)
-        self.log("validation_loss", loss, on_step=False, on_epoch=True, prog_bar=True, logger=True)
+        self.log("val_loss", loss, on_step=False, on_epoch=True, prog_bar=True, logger=True)
         return loss
 
     def test_step(self, batch: Tuple[Tensor, Tensor, Tensor], batch_idx: int) -> Tensor:
@@ -296,7 +294,10 @@ class SAINT(LightningModule):
                     m.train()
         x_categ, x_cont, _ = batch
         y_pred = self(x_categ, x_cont)
-        return y_pred
+        if self.dim_target > 1:
+            return nn.Softmax(dim=-1)(y_pred)
+        else:
+            return y_pred
 
     @staticmethod
     def _classification_loss(y_pred: Tensor, target: Tensor) -> Tensor:
@@ -305,7 +306,6 @@ class SAINT(LightningModule):
         :param y_pred: Values predicted
         :param target: Values to predict
         """
-        nn.CrossEntropyLoss()
         return f.cross_entropy(y_pred, target)
 
     @staticmethod
